@@ -26,7 +26,7 @@
 #include "auth.h"
 
 #ifndef VERSION
-#define VERSION "???"
+#define VERSION "0.14"
 #endif
 
 #define PRGNAME "axgetlist"
@@ -240,11 +240,12 @@ int convert_entry(char *data, char *format, char *result)
 {
   int msgnum = -1;
   char flag = '\0';
-  int size;
+  int size = 0;
   char dest[32];
   char bbs[32];
+  char fulldest[65];
   char src[32];
-  char date[8];
+  char date[16];
   char subj[256];
   char dd[8], dm[8], dy[8];
   struct tm *tim;
@@ -254,7 +255,10 @@ int convert_entry(char *data, char *format, char *result)
   char tag[32];
   char value[256];
   int in_macro = 0;
-  
+
+  /* Initialize bbs in case it is not present in the data */
+  bbs[0] = '\0';
+
   /* scan format string and interpret data */
   p = format;
   q = data;
@@ -373,7 +377,7 @@ int convert_entry(char *data, char *format, char *result)
        }
   }
 
-  p = strchr(datefmt, 'm');   /* year */
+  p = strchr(datefmt, 'y');   /* year */
   if (p != NULL)
   {
     strcpy(dy, "");
@@ -382,15 +386,25 @@ int convert_entry(char *data, char *format, char *result)
        { strncat(dy, q, 1); q++; p++; }
   }
 
-  sprintf(result, "%i  %c %6i %-6s@%-6s %-6s %02i%02i%02i %s", msgnum,
+  /* Format full destination depending on whether or not bbs is present */
+  if (bbs[0] == '\0')
+    sprintf(fulldest, "%-13s", dest);
+  else
+    sprintf(fulldest, "%-6s@%-6s", dest, bbs);
+
+  /* Ensure strings of only digits, zero-padded, for the date components */
+  sprintf(dd, "%02d", atoi(dd));
+  sprintf(dm, "%02d", atoi(dm));
+  sprintf(dy, "%04d", atoi(dy));
+
+  sprintf(result, "%i  %c %6i %s %-6s %s%s%s %s", msgnum,
                                                                flag,
                                                                size,
-                                                               dest,
-                                                               bbs,
+                                                               fulldest,
                                                                src,
-                                                               atoi(dy),
-                                                               atoi(dm),
-                                                               atoi(dd),
+                                                               dy + strlen(dy) - 2,
+                                                               dm,
+                                                               dd,
                                                                subj);
   return msgnum;
 }
@@ -544,7 +558,7 @@ int main(int argc, char **argv)
        case 's': startfrom = strtol(optarg, &endpos, 10);
                  if (*endpos) { help(); exit(1); }
                  break;
-       case 'v': printf("%s / ax25mail-utils %s", PRGNAME, VERSION);
+       case 'v': printf("%s / ax25mail-utils %s\n", PRGNAME, VERSION);
                  exit(0);
                  break;
        case 'h':
@@ -595,7 +609,10 @@ int main(int argc, char **argv)
       if (msgnum > 0) add_line(bcall, msgnum, line);
       /*if (msgnum > 0) printf("%s\n", line);*/
     } while(msgnum > 0);
-    wait_prompt(stream);
+
+    /* Prompt may be in the line that ended the parse, so check before waiting */
+    if (s[strlen(s)-1] != '>')
+      wait_prompt(stream);
   }
 
   send_commands(stream, cmd_disc, 0);
